==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.tools.files/src/com/openexchange/office/tools/files/FolderHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.tools.files;

import org.apache.commons.logging.Log;

import com.openexchange.exception.OXException;
import com.openexchange.file.storage.FileStorageFolder;
import com.openexchange.file.storage.FileStorageFolderType;
import com.openexchange.file.storage.FileStoragePermission;
import com.openexchange.file.storage.TypeAware;
import com.openexchange.file.storage.composition.FileID;
import com.openexchange.file.storage.composition.FolderID;
import com.openexchange.file.storage.composition.IDBasedFolderAccess;
import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
import com.openexchange.server.ServiceLookup;
import com.openexchange.session.Session;

public class FolderHelper
{
    private static final Log LOG = com.openexchange.log.Log.loggerFor(FolderHelper.class);

    public static final int FOLDER_PERMISSIONS_READ = 0;

    public static final int FOLDER_PERMISSIONS_WRITE = 1;

    public static final int FOLDER_PERMISSIONS_FOLDER = 2;

    public static final int FOLDER_PERMISSIONS_SIZE = 3;

    /**
     * Determines if a folder is a trash folder or not.
     * If folder is in trash, it is also defined as trash folder
     *
     * @param folder
     *  The folder to be checked.
     *
     * @return
     *  TRUE if the folder is a trash folder or in trash folder, otherwise FALSE.
     */
    public static boolean isFolderTrashOrInTrash(FileStorageFolder folder) {
        return ((null != folder) && (TypeAware.class.isInstance(folder) && FileStorageFolderType.TRASH_FOLDER.equals(((TypeAware)folder).getType())));
    }

    /**
     * Determines if a folder is a root folder or not.
     *
     *  The folder to be checked.
     *
     * @return
     *  TRUE if the folder is a trash folder, otherwise FALSE.
     */
    public static boolean isRootFolder(FileStorageFolder folder) {
        // Uses a workaround in case isRootFolder is false but the id = 0
        // Treat this folder as root folder regarding the result of
        // isRootFolder.
        return (folder.isRootFolder() || folder.getId().equals("0"));
    }

    /**
     * Retrieve user read permission for a certain folder.
     *
     * @param fileAccess
     *  The file access to be used to retrieve the write
     *  permissions of the user.
     *
     * @param folderId
     *  The folder id where want to know the write permissions
     *  of the user.
     *
     * @return
     *  TRUE if the user has read permission in the provided folder,
     *  other FALSE.
     */
    public static boolean folderHasReadAccess(IDBasedFolderAccess folderAccess, String folderId) {
        boolean ret = false;

        int[] result = getFolderPermissions(folderAccess, folderId);
        if (null != result && result.length >= 3) {
            int readPermission = result[FOLDER_PERMISSIONS_READ];
            ret = (readPermission > FileStoragePermission.NO_PERMISSIONS);
        }
        return ret;
    }

    /**
     * Retrieve user write permission for a certain folder.
     *
     * @param fileAccess
     *  The file access to be used to retrieve the write
     *  permissions of the user.
     *
     * @param folderId
     *  The folder id where want to know the write permissions
     *  of the user.
     *
     * @return
     *  TRUE if the user has write permission in the provided folder,
     *  other FALSE.
     */
    public static boolean folderHasWriteAccess(IDBasedFolderAccess folderAccess, String folderId) {
        boolean ret = false;

        int[] result = getFolderPermissions(folderAccess, folderId);
        if (null != result && result.length >= 3) {
            int writePermission = result[FOLDER_PERMISSIONS_WRITE];
            ret = (writePermission > FileStoragePermission.NO_PERMISSIONS);
        }
        return ret;
    }

    /**
     * Retrieve user create permission for a certain folder.
     *
     * @param fileAccess
     *  The file access to be used to retrieve the create
     *  permissions of the user.
     *
     * @param folderId
     *  The folder id where want to know the create permissions
     *  of the user.
     *
     * @return
     *  TRUE if the user has the create permission in the provided folder,
     *  other FALSE.
     */
    public static boolean folderHasCreateAccess(IDBasedFolderAccess folderAccess, String folderId) {
        boolean ret = false;

        int[] result = getFolderPermissions(folderAccess, folderId);
        if (null != result && result.length >= 3) {
            int createPermission = result[FOLDER_PERMISSIONS_FOLDER];
            ret = (createPermission >= FileStoragePermission.CREATE_OBJECTS_IN_FOLDER);
        }
        return ret;
    }

    /**
     * Retrieve the user permissions for the provided folder id.
     * @param folderAccess
     *  The folder access used to retrieve the user permissions.
     * @param folderId
     *  The folder id to retrieve the user permissions.
     *
     * @return
     *  An array with three entries for read, write and folder permissions or
     *  null if the method is unable to retrieve the permissions.
     */
    public static int[] getFolderPermissions(IDBasedFolderAccess folderAccess, String folderId) {
        int[] result = null;


        try {
            // retrieve the folder instance from the folder id
            final FileStorageFolder folder = folderAccess.getFolder(folderId);

            if (folder != null) {
                final FileStoragePermission permission = folder.getOwnPermission();

                int readPermission = permission.getReadPermission();
                int writePermission = permission.getWritePermission();
                int folderPermission = permission.getFolderPermission();

                // create array with user permissions for the folder
                result = new int[FOLDER_PERMISSIONS_SIZE];
                result[FOLDER_PERMISSIONS_READ] = readPermission;
                result[FOLDER_PERMISSIONS_WRITE] = writePermission;
                result[FOLDER_PERMISSIONS_FOLDER] = folderPermission;
            }
        } catch (final Exception e) {
            LOG.warn("GetFolderPermissions - retrieving user permissions for folder failed with exception", e);
        }

        return result;
    }

    /**
     * Checks that a user permissions for a folder id are
     * sufficient for provided rights (read, write & create files).
     *
     * @param folderAccess the folder access to retrieve the user permissions.
     * @param folderId the folder id to retrieve the user permissions.
     * @param read true to ask for read permissions
     * @param write true to ask for write permissions
     * @param create true to ask for create permissions
     * @return true if the folder provides the asked permissions, otherwise false
     */
    public static boolean providesFolderPermissions(IDBasedFolderAccess folderAccess, String folderId, boolean read, boolean write, boolean create) {
        boolean result = false;

        try {
            // retrieve the folder instance from the folder id
            final FileStorageFolder folder = folderAccess.getFolder(folderId);

            if (folder != null) {
                final FileStoragePermission permission = folder.getOwnPermission();

                int readPermission = permission.getReadPermission();
                int writePermission = permission.getWritePermission();
                int folderPermission = permission.getFolderPermission();

                result = true;
                if (read) {
                    result = (readPermission > FileStoragePermission.NO_PERMISSIONS);
                }
                if (write) {
                    result &= (writePermission > FileStoragePermission.NO_PERMISSIONS);
                }
                if (create) {
                    result &= (folderPermission >= FileStoragePermission.CREATE_OBJECTS_IN_FOLDER);
                }
            }
        } catch (final Exception e) {
            LOG.warn("GetFolderPermissions - retrieving user permissions for folder failed with exception", e);
        }

        return result;
    }

    /**
     * Retrieves the folder id from the provided file id.
     * </br><b>ATTENTION: This folder id is user-dependent and should never be used
     * in a different user-context.</b>
     *
     * @param folderAccess the folder access to be used to retrieve the folder id.
     * @param id the file id where one wants to retrieve the parent folder
     * @return the folder id or null if retrieving the id failed
     */
    public static String getFolderId(final IDBasedFolderAccess folderAccess, final String id) {
        String result = null;

        try {
            final FileID fileID = new FileID(id);
            final FolderID folderID = new FolderID(fileID.getService(), fileID.getAccountId(), fileID.getFolderId());

            result = folderID.toUniqueID();
        } catch (final Exception e) {
            LOG.error("GetFolderId - retrieving the folder id from a file_id failed with exception:", e);
        }

        return result;
    }

    /**
     * Retrieve a folder access.
     *
     * @param session
     *  The session associated with the folder access.
     *
     * @return
     *  The folder access or null if no folder access is available.
     *
     * @throws OXException
     */
    public static IDBasedFolderAccess getFolderAccess(ServiceLookup servicesDEPRECATED, Session session) throws OXException {
        IDBasedFolderAccessFactory factory = ServiceLookupRegistry.get().getService(IDBasedFolderAccessFactory.class);
        return factory.createAccess(session);
    }

}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.tools.files/src/com/openexchange/office/tools/files/FolderHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.tools.files;

import org.apache.commons.logging.Log;

import com.openexchange.exception.OXException;
import com.openexchange.file.storage.FileStorageFolder;
import com.openexchange.file.storage.FileStorageFolderType;
import com.openexchange.file.storage.FileStoragePermission;
import com.openexchange.file.storage.TypeAware;
import com.openexchange.file.storage.composition.FileID;
import com.openexchange.file.storage.composition.FolderID;
import com.openexchange.file.storage.composition.IDBasedFolderAccess;
import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
import com.openexchange.office.tools.osgi.ServiceLookupRegistryService;
import com.openexchange.server.ServiceLookup;
import com.openexchange.session.Session;

public class FolderHelper
{
    private static final Log LOG = com.openexchange.log.Log.loggerFor(FolderHelper.class);

    public static final int FOLDER_PERMISSIONS_READ = 0;

    public static final int FOLDER_PERMISSIONS_WRITE = 1;

    public static final int FOLDER_PERMISSIONS_FOLDER = 2;

    public static final int FOLDER_PERMISSIONS_SIZE = 3;

    /**
     * Determines if a folder is a trash folder or not.
     * If folder is in trash, it is also defined as trash folder
     *
     * @param folder
     *  The folder to be checked.
     *
     * @return
     *  TRUE if the folder is a trash folder or in trash folder, otherwise FALSE.
     */
    public static boolean isFolderTrashOrInTrash(FileStorageFolder folder) {
        return ((null != folder) && (TypeAware.class.isInstance(folder) && FileStorageFolderType.TRASH_FOLDER.equals(((TypeAware)folder).getType())));
    }

    /**
     * Determines if a folder is a root folder or not.
     *
     *  The folder to be checked.
     *
     * @return
     *  TRUE if the folder is a trash folder, otherwise FALSE.
     */
    public static boolean isRootFolder(FileStorageFolder folder) {
        // Uses a workaround in case isRootFolder is false but the id = 0
        // Treat this folder as root folder regarding the result of
        // isRootFolder.
        return (folder.isRootFolder() || folder.getId().equals("0"));
    }

    /**
     * Retrieve user read permission for a certain folder.
     *
     * @param fileAccess
     *  The file access to be used to retrieve the write
     *  permissions of the user.
     *
     * @param folderId
     *  The folder id where want to know the write permissions
     *  of the user.
     *
     * @return
     *  TRUE if the user has read permission in the provided folder,
     *  other FALSE.
     */
    public static boolean folderHasReadAccess(IDBasedFolderAccess folderAccess, String folderId) {
        boolean ret = false;

        int[] result = getFolderPermissions(folderAccess, folderId);
        if (null != result && result.length >= 3) {
            int readPermission = result[FOLDER_PERMISSIONS_READ];
            ret = (readPermission > FileStoragePermission.NO_PERMISSIONS);
        }
        return ret;
    }

    /**
     * Retrieve user write permission for a certain folder.
     *
     * @param fileAccess
     *  The file access to be used to retrieve the write
     *  permissions of the user.
     *
     * @param folderId
     *  The folder id where want to know the write permissions
     *  of the user.
     *
     * @return
     *  TRUE if the user has write permission in the provided folder,
     *  other FALSE.
     */
    public static boolean folderHasWriteAccess(IDBasedFolderAccess folderAccess, String folderId) {
        boolean ret = false;

        int[] result = getFolderPermissions(folderAccess, folderId);
        if (null != result && result.length >= 3) {
            int writePermission = result[FOLDER_PERMISSIONS_WRITE];
            ret = (writePermission > FileStoragePermission.NO_PERMISSIONS);
        }
        return ret;
    }

    /**
     * Retrieve user create permission for a certain folder.
     *
     * @param fileAccess
     *  The file access to be used to retrieve the create
     *  permissions of the user.
     *
     * @param folderId
     *  The folder id where want to know the create permissions
     *  of the user.
     *
     * @return
     *  TRUE if the user has the create permission in the provided folder,
     *  other FALSE.
     */
    public static boolean folderHasCreateAccess(IDBasedFolderAccess folderAccess, String folderId) {
        boolean ret = false;

        int[] result = getFolderPermissions(folderAccess, folderId);
        if (null != result && result.length >= 3) {
            int createPermission = result[FOLDER_PERMISSIONS_FOLDER];
            ret = (createPermission >= FileStoragePermission.CREATE_OBJECTS_IN_FOLDER);
        }
        return ret;
    }

    /**
     * Retrieve the user permissions for the provided folder id.
     * @param folderAccess
     *  The folder access used to retrieve the user permissions.
     * @param folderId
     *  The folder id to retrieve the user permissions.
     *
     * @return
     *  An array with three entries for read, write and folder permissions or
     *  null if the method is unable to retrieve the permissions.
     */
    public static int[] getFolderPermissions(IDBasedFolderAccess folderAccess, String folderId) {
        int[] result = null;


        try {
            // retrieve the folder instance from the folder id
            final FileStorageFolder folder = folderAccess.getFolder(folderId);

            if (folder != null) {
                final FileStoragePermission permission = folder.getOwnPermission();

                int readPermission = permission.getReadPermission();
                int writePermission = permission.getWritePermission();
                int folderPermission = permission.getFolderPermission();

                // create array with user permissions for the folder
                result = new int[FOLDER_PERMISSIONS_SIZE];
                result[FOLDER_PERMISSIONS_READ] = readPermission;
                result[FOLDER_PERMISSIONS_WRITE] = writePermission;
                result[FOLDER_PERMISSIONS_FOLDER] = folderPermission;
            }
        } catch (final Exception e) {
            LOG.warn("GetFolderPermissions - retrieving user permissions for folder failed with exception", e);
        }

        return result;
    }

    /**
     * Checks that a user permissions for a folder id are
     * sufficient for provided rights (read, write & create files).
     *
     * @param folderAccess the folder access to retrieve the user permissions.
     * @param folderId the folder id to retrieve the user permissions.
     * @param read true to ask for read permissions
     * @param write true to ask for write permissions
     * @param create true to ask for create permissions
     * @return true if the folder provides the asked permissions, otherwise false
     */
    public static boolean providesFolderPermissions(IDBasedFolderAccess folderAccess, String folderId, boolean read, boolean write, boolean create) {
        boolean result = false;

        try {
            // retrieve the folder instance from the folder id
            final FileStorageFolder folder = folderAccess.getFolder(folderId);

            if (folder != null) {
                final FileStoragePermission permission = folder.getOwnPermission();

                int readPermission = permission.getReadPermission();
                int writePermission = permission.getWritePermission();
                int folderPermission = permission.getFolderPermission();

                result = true;
                if (read) {
                    result = (readPermission > FileStoragePermission.NO_PERMISSIONS);
                }
                if (write) {
                    result &= (writePermission > FileStoragePermission.NO_PERMISSIONS);
                }
                if (create) {
                    result &= (folderPermission >= FileStoragePermission.CREATE_OBJECTS_IN_FOLDER);
                }
            }
        } catch (final Exception e) {
            LOG.warn("GetFolderPermissions - retrieving user permissions for folder failed with exception", e);
        }

        return result;
    }

    /**
     * Retrieves the folder id from the provided file id.
     * </br><b>ATTENTION: This folder id is user-dependent and should never be used
     * in a different user-context.</b>
     *
     * @param folderAccess the folder access to be used to retrieve the folder id.
     * @param id the file id where one wants to retrieve the parent folder
     * @return the folder id or null if retrieving the id failed
     */
    public static String getFolderId(final IDBasedFolderAccess folderAccess, final String id) {
        String result = null;

        try {
            final FileID fileID = new FileID(id);
            final FolderID folderID = new FolderID(fileID.getService(), fileID.getAccountId(), fileID.getFolderId());

            result = folderID.toUniqueID();
        } catch (final Exception e) {
            LOG.error("GetFolderId - retrieving the folder id from a file_id failed with exception:", e);
        }

        return result;
    }

    /**
     * Retrieve a folder access.
     *
     * @param session
     *  The session associated with the folder access.
     *
     * @return
     *  The folder access or null if no folder access is available.
     *
     * @throws OXException
     */
    public static IDBasedFolderAccess getFolderAccess(ServiceLookup servicesDEPRECATED, Session session) throws OXException {
        IDBasedFolderAccessFactory factory = ServiceLookupRegistryService.getInstance().getService(IDBasedFolderAccessFactory.class);
        IDBasedFolderAccess res = factory.createAccess(session);
        return res;
    }

}
